# Potential Contrasting Coarse Graining

## Introduction

[Potential contrasting](https://pubs.acs.org/doi/10.1021/acs.jctc.2c00616) is an efficient method for learning a potential energy function that can reproduce an ensemble of molecular conformations. It can be easily applied to can learn coarse-grained force fields based on all-atom simulations. It generalizes the [noise contrastive estimation method](https://proceedings.mlr.press/v9/gutmann10a) to use complex unnormalized noise distributions constructed using molecular dynamics techniques such as [umbrella sampling](https://en.wikipedia.org/wiki/Umbrella_sampling).

## Getting Help

Need help? Checkout the [documentation](https://pccg.readthedocs.io).
